#Script for performing fuzzy overlay, to analyze potential for gold deposits
#Created by Nevada State Geologic Survey
#Date: March 15,2011

#import system modules
import arcpy
from arcpy.sa import *
import os

#set geoprocessing environments
arcpy.env.overwriteOutput = True
arcpy.env.workspace = os.path.join(os.path.dirname(os.getcwd()), "data", "Carlin.gdb")
arcpy.env.scratchWorkspace = os.path.join(os.path.dirname(os.getcwd()), "data", "scratch")
arcpy.env.extent = "LanderCounty"
arcpy.env.mask = "LanderCounty"
arcpy.env.cellSize = "Geology"

arcpy.CheckOutExtension("Spatial")

samples = "SedimentSamples"

#create surfaces
antimony = NaturalNeighbor(samples, "NAA_SB")
arsenic = NaturalNeighbor(samples, "NAA_AS")
potassium = NaturalNeighbor(samples, "NAA_K")

#calculate fuzzy membership
antimonyFMS = FuzzyMembership(antimony, FuzzyMSLarge(1, 1))
arsenicFMS = FuzzyMembership(arsenic, FuzzyMSLarge(1, 1))
potassiumFMS = FuzzyMembership(potassium, FuzzyMSSmall(1, 1))

#combine antimony and arsenic fuzzy membersship
mineralfactor = FuzzyOverlay([antimonyFMS, arsenicFMS], "OR")

#combine mineral factor with potassium membership
lithadjmineralfactor = FuzzyOverlay([mineralfactor, potassiumFMS], "AND")

#ALTERNATE way to combine antimony and arsenic fuzzy membersship with potassium membership using nesting
#lithadjmineralfactor = FuzzyOverlay([FuzzyOverlay([antimonyFMS, arsenicFMS], "OR"), potassiumFMS], "AND")

#reclassify the geologies into continuous values (close to 100=good, close to 0=bad)
remap = [['TPC', 50], ['TRPE', 60], ['TMF', 50], ['TMV', 50], ['UPZ', 90], ['LMZ', 40], ['Q', 50], ['LPZ', 90], ['QV', 50], ['TPV', 50], ['TPF', 50], ['KG', 0], ['C', 85], ['UPZE', 90], ['P', 60], ['TI', 0], ['LTV', 50], ['LPZE', 90], ['JG', 0], ['KC', 0], ['UPZC', 75], ['LMZV', 55], ['TRG', 0], ['KG2', 0], ['JMI', 0]]
georeclass = Reclassify("Geology", "CODE", RemapValue(remap))

#the reclassified geology must be converted to a floating point raster, and values divided by 100
geofactor = georeclass / 100.0

#combine the geology factor and mineral factor with Fuzzy overlay
goldpossibility = FuzzyOverlay([lithadjmineralfactor, geofactor], "GAMMA", 0.9)
goldpossibility.save("GoldPossibility")

#extract the areas that have a fuzzy possibility of > 0.70
bestchance = SetNull(goldpossibility < 0.70, 1)
bestchance.save("BestChance")

print "Finished"
